-- KabSounds.lua
-- Script for Fendt Farmer 310/312 LSA
--
-- Author Rival
-- 05.01.2016
-- Version 1.1 @26.10.2016
	--> converted to FS17
-- Version 1.2 @05.11.2016
	--> added indoorsound change when door/windows are open

KabSounds = {};

function KabSounds.prerequisitesPresent(specializations)
    return true;
end;

function KabSounds:load(savegame)
	
	self.soundAdj = {};
	local i=0;
    while true do
        local key = string.format("vehicle.indoorsoundAdjustment.animation(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        local animName = getXMLString(self.xmlFile, key.."#name");
        local lowpassGain = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#lowpassGain"), 0.5);
        local volumeFactor = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#volumeFactor"), 0.5);
		self.soundAdj[i] = {};
		self.soundAdj[i].animName = animName;
		self.soundAdj[i].volumeFactor = volumeFactor;
		self.soundAdj[i].lowpassGain = lowpassGain;
        i = i +1;
    end;
	
	if self.isClient then
	    self.sampleOpenPipe = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.OpenPipe", nil, self.baseDirectory);
	    self.sampleClosePipe = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.ClosePipe", nil, self.baseDirectory);
	    self.sampleOpenCopper = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.OpenCopper", nil, self.baseDirectory);
	    self.sampleCloseCopper = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.CloseCopper", nil, self.baseDirectory);
		self.sampleOpenDoorL = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Sound/7RopenDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorL = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Sound/7RcloseDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorR = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Sound/7RopenDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorR = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Sound/7RcloseDoor.wav", self.baseDirectory, self.components[1].node);
	end;
end;
--function KabSounds:postLoad(savegame)
--	for k,v in pairs(self.sampleMotor) do print(k,v) end
--end;
function KabSounds:delete()
    
    if self.isClient then
	     SoundUtil.deleteSample(self.sampleOpenPipe);
	     SoundUtil.deleteSample(self.sampleClosePipe);
	     SoundUtil.deleteSample(self.sampleOpenCopper);
	     SoundUtil.deleteSample(self.sampleCloseCopper);
    end;
	if self.sampleOpenDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorL);
	end;
	if self.sampleOpenDoorR ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorR);
	end;
	if self.sampleCloseDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorL);
	end;
	if self.sampleCloseDoorR ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorR);
	end;
end;
function KabSounds:mouseEvent(posX, posY, isDown, isUp, button)
end;
function KabSounds:keyEvent(unicode, sym, modifier, isDown)
end;
function KabSounds:update(dt)
    if self:getIsActive() and self.isClient then
		if self.isEntered then
			if self:getIsAnimationPlaying("leftDoor") and self:getIsActiveForSound() then
				if self.animations["leftDoor"].currentSpeed > 0 and self.animations["leftDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorL, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorL,1,1,nil);
					end;
				elseif self.animations["leftDoor"].currentSpeed < 0 and self.animations["leftDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorL, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorL,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("rightDoor") and self:getIsActiveForSound() then
				if self.animations["rightDoor"].currentSpeed > 0 and self.animations["rightDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorR, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorR,1,1,nil);
					end;
				elseif self.animations["rightDoor"].currentSpeed < 0 and self.animations["rightDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorR, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorR,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("toggleChopper") and self:getIsActiveForSound() then
				if self.animations["toggleChopper"].currentSpeed > 0 and self.animations["toggleChopper"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenCopper, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenCopper,1,1,nil);
					end;
				elseif self.animations["toggleChopper"].currentSpeed < 0 and self.animations["toggleChopper"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseCopper, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseCopper,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("ShnekAnimation") and self:getIsActiveForSound() then
				if self.animations["ShnekAnimation"].currentSpeed > 0 and self.animations["ShnekAnimation"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenPipe, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenPipe,1,1,nil);
					end;
				elseif self.animations["ShnekAnimation"].currentSpeed < 0 and self.animations["ShnekAnimation"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleClosePipe, 1.5*dt) then
						SoundUtil.playSample(self.sampleClosePipe,1,1,nil);
					end;
				end;
			end;
			local sound=false;
			for i=0, #self.soundAdj do
				if self.animations[self.soundAdj[i].animName] ~= nil and self.animations[self.soundAdj[i].animName].currentTime > 500 then
					self.sampleMotor.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotor.indoorVolumeFactor);
					self.sampleMotor.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotor.indoorLowpassGain);
					self.sampleMotorStart.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStart.indoorVolumeFactor);
					self.sampleMotorStart.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStart.indoorLowpassGain);
					self.sampleMotorStop.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStop.indoorVolumeFactor);
					self.sampleMotorStop.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStop.indoorLowpassGain);
					
					self.sampleMotorRun.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorRun.indoorVolumeFactor);
					self.sampleMotorRun.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorRun.indoorLowpassGain);
					sound=true;
				else
					if not sound then
						self.sampleMotor.indoorVolumeFactor = 0.55;
						self.sampleMotor.indoorLowpassGain = 0.2;
						self.sampleMotorStart.indoorVolumeFactor = 0.55;
						self.sampleMotorStart.indoorLowpassGain = 0.2;
						self.sampleMotorStop.indoorVolumeFactor = 0.55;
						self.sampleMotorStop.indoorLowpassGain = 0.2;
						
						self.sampleMotorRun.indoorVolumeFactor = 0.6;
						self.sampleMotorRun.indoorLowpassGain = 0.2;
					end;
				end;
			end;
			SoundUtil.onCameraSwitched(self.activeCamera.isInside);
		end;
    end;
end;
function KabSounds:updateTick(dt)
end;
function KabSounds:draw()    
end;